@@ -4,7 +4,7 @@ import uvicorn
 from starlette.applications import Starlette
 
 
-_DEFAULTS = {"port": "8080"}
+_DEFAULTS = {"port": 8080}
 
 
 def run(app: Starlette, **kwargs):
@@ -14,5 +14,5 @@ def run(app: Starlette, **kwargs):
     overrides = {}
     port = os.environ.get("SERVER_PORT")
     if port is not None:
-        overrides["port"] = port
+        overrides["port"] = int(port)
     uvicorn.run(app, **{**_DEFAULTS, **overrides, **kwargs})
